<?php

declare(strict_types=1);

namespace Drupal\ui_patterns_views\Plugin\UiPatterns\Source;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\Context\ContextDefinition;
use Drupal\Core\Plugin\Context\EntityContextDefinition;

/**
 * Plugin base source to handle the view field.
 *
 * @Source(
 *   id = "view_field",
 *   label = @Translation("View field"),
 *    description = @Translation("View field."),
 *   prop_types = {
 *       "slot"
 *     },
 *  )
 */
class ViewFieldSource extends ViewsSourceBase {

  /**
   * {@inheritdoc}
   */
  public function getContextDefinitions() {
    // Context for views entity type.
    $entity_context = EntityContextDefinition::fromEntityTypeId('view')
      ->setRequired()
      ->setLabel('Views');
    $plugin_type_context = new ContextDefinition('string');
    $plugin_type_context
      ->setRequired()
      ->addConstraint('AllowedValues', ['row']);
    return [
      'entity' => $entity_context,
      'plugin_type' => $plugin_type_context,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    $form = parent::settingsForm($form, $form_state);
    $view = $this->getContextValue('entity');
    $current_display = $this->getContextValue('display');
    $default_settings = $this->getSettings();
    $options = [];
    foreach ($view->get('display') as $display_id => $display) {
      if ($current_display != $display_id || empty($display['display_options']['fields'])) {
        continue;
      }

      foreach ($display['display_options']['fields'] as $field) {
        $options[$field['id']] = !empty($field['label']) ? $field['label'] : $field['field'];
      }
    }
    $form['ui_patterns_views_field'] = [
      '#type' => 'select',
      '#title' => t('Fields'),
      '#description' => t('Select one or multiple fields to insert in this slot.'),
      '#options' => $options,
      '#default_value' => $default_settings['ui_patterns_views_field'] ?? [],
      '#required' => TRUE,
    ];
    return $form;
  }

}
