<?php

declare(strict_types=1);

namespace Drupal\ui_patterns_views\Plugin\UiPatterns\Source;

use Drupal\Component\Render\MarkupInterface;
use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ui_patterns\SourcePluginBase;

/**
 * Plugin implementation of the source.
 */
abstract class ViewsSourceBase extends SourcePluginBase {

  /**
   * {@inheritdoc}
   */
  public function getPropValue(): mixed {
    $output = $this->getSettingsFromConfiguration('output');
    // Value needs to be render array so slots can handle muliple sources.
    if ($output instanceof MarkupInterface) {
      return ['#markup' => $output->__toString()];
    }
    if (is_scalar($output)) {
      return ['#markup' => $output];
    }
    return $output;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    $form = parent::settingsForm($form, $form_state);
    $form['label_map'] = [
      "#type" => "label",
      "#title" => $this->propDefinition['title'] . ": " . $this->label(),
    ];
    return $form;
  }

  /**
   * Get the settings from the plugin configuration.
   *
   * @param string|null $key
   *   Optional key to retrieve.
   *
   * @return mixed|null
   *   The requested nested value from configuration,
   */
  protected function getSettingsFromConfiguration(?string $key = NULL) {
    $parents = ['settings', 'ui_patterns_views'];
    if ($key) {
      $parents[] = $key;
    }
    $configuration = $this->getConfiguration();
    return NestedArray::getValue($configuration, $parents);
  }

}
